//
//  MultiTableSampleViewController.m
//  MultiTableSample
//
//  Created by Min-gu, Kim on 10. 9. 8..
//  Copyright 더블가이 2010. All rights reserved.
//

#import "MultiTableSampleViewController.h"
#define daumSocietyXML @"http://media.daum.net/rss/part/primary/society/rss2.xml"
#define daumDigitalXML @"http://media.daum.net/rss/part/primary/digital/rss2.xml"

@implementation MultiTableSampleViewController
@synthesize societyTable, digitalTable;
@synthesize societyItems, digitalItems;

// Implement viewDidLoad to do additional setup after loading the view, typically from a nib.
- (void)viewDidLoad {
    [super viewDidLoad];
	
	[self setSocietyItems:[[NSMutableArray alloc] init]];
	[self setDigitalItems:[[NSMutableArray alloc] init]];
}

- (void) viewWillAppear:(BOOL)animated {
	[super viewWillAppear:animated];
	
	[self getSocietyItems];
	[self getDigitalItems];
}

- (void)didReceiveMemoryWarning {
	// Releases the view if it doesn't have a superview.
    [super didReceiveMemoryWarning];
	
	// Release any cached data, images, etc that aren't in use.
}

- (void)viewDidUnload {
	// Release any retained subviews of the main view.
	// e.g. self.myOutlet = nil;
}

- (void)dealloc {
	[self setSocietyTable:nil];
	[self setDigitalTable:nil];
	
	[self setSocietyItems:nil];
	[self setDigitalItems:nil];
	
    [super dealloc];
}

#pragma mark Instance Method
- (void) getSocietyItems {
	NSURL* url = [NSURL URLWithString:daumSocietyXML];

	NSString* xmlStr = [NSString stringWithContentsOfURL:url encoding:NSUTF8StringEncoding error:nil];
	
	APDocument* doc = [APDocument documentWithXMLString:xmlStr];
	APElement*	rootElement = [doc rootElement];
	
	NSArray* childElements = [rootElement childElements];
	
	for(APElement* child in childElements) {
		if([[child name] isEqualToString:@"channel"] == YES) {
			NSArray* channelElements = [child childElements];
			for(APElement* channel in channelElements) {
				if([[channel name] isEqualToString:@"item"] == YES) {
					[societyItems addObject:[self getItem:channel]];
				}
			}
		}
	}
	
	[societyTable reloadData];
}

- (void) getDigitalItems {
	NSURL* url = [NSURL URLWithString:daumDigitalXML];
	
	NSString* xmlStr = [NSString stringWithContentsOfURL:url encoding:NSUTF8StringEncoding error:nil];
	
	APDocument* doc = [APDocument documentWithXMLString:xmlStr];
	APElement*	rootElement = [doc rootElement];
	
	NSArray* childElements = [rootElement childElements];
	
	for(APElement* child in childElements) {
		if([[child name] isEqualToString:@"channel"] == YES) {
			NSArray* channelElements = [child childElements];
			for(APElement* channel in channelElements) {
				if([[channel name] isEqualToString:@"item"] == YES) {
					[digitalItems addObject:[self getItem:channel]];
				}
			}
		}
	}
	
	[digitalTable reloadData];
}

- (item *)getItem:(APElement *)itemElement {
	NSArray* childElements = [itemElement childElements];
	
	item* obj = [[[item alloc] init] autorelease];
	
	for(APElement* child in childElements) {
		if([[child name] isEqualToString:@"title"] == YES) {
			[obj setTitle:[child value]];
		}
		if([[child name] isEqualToString:@"description"] == YES) {
			[obj setDescription:[child value]];
		}
		if([[child name] isEqualToString:@"link"] == YES) {
			[obj setLink:[child value]];
		}
	}
	
	return obj;
}

#pragma mark UITableView dataSource
// Customize the number of rows in the table view.
- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section {
	if(tableView == societyTable) {
		return [societyItems count];
	} else if(tableView == digitalTable) {
		return [digitalItems count];
	}
	else
		return 0;
}


// Customize the appearance of table view cells.
- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath {
    
    static NSString *CellIdentifier = @"Cell";
    
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:CellIdentifier];
    if (cell == nil) {
        cell = [[[UITableViewCell alloc] initWithStyle:UITableViewCellStyleDefault reuseIdentifier:CellIdentifier] autorelease];
    }
	
	// Configure the cell.
	if(tableView == societyTable) {
		
		item* obj = (item *)[societyItems objectAtIndex:indexPath.row];
		[[cell textLabel] setText:[obj title]];
		
	} else if(tableView == digitalTable) {
		
		item* obj = (item *)[digitalItems objectAtIndex:indexPath.row];
		[[cell textLabel] setText:[obj title]];
	}
	
    return cell;
}
@end
